==> freecad_0.18.4+dfsg2.orig.tar.xz: FreeCAD-0.18.4/src/Mod/Image/Gui/Resources/translations/Image_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="lt" sourcelanguage="en">
  <context>
    <name>Dialog</name>
    <message>
      <location filename="../../../ImageTools/_CommandImageScaling.py" line="134"/>
      <source>Scale image plane</source>
      <translation type="unfinished">Scale image plane</translation>
    </message>
    <message>
      <location filename="../../../ImageTools/_CommandImageScaling.py" line="135"/>
      <source>Distance</source>
      <translation type="unfinished">Distance</translation>
    </message>
    <message>
      <location filename="../../../ImageTools/_CommandImageScaling.py" line="136"/>
      <source>Select first point</source>
      <translation type="unfinished">Select first point</translation>
    </message>
    <message>
      <location filename="../../../ImageTools/_CommandImageScaling.py" line="154"/>
      <source>&lt;font color='red'&gt;Enter distance&lt;/font&gt;</source>
      <translation type="unfinished">&lt;font color='red'&gt;Enter distance&lt;/font&gt;</translation>
    </message>
    <message>
      <location filename="../../../ImageTools/_CommandImageScaling.py" line="157"/>
      <source>&lt;font color='red'&gt;Select ImagePlane&lt;/font&gt;</source>
      <translation type="unfinished">&lt;font color='red'&gt;Select ImagePlane&lt;/font&gt;</translation>
    </message>
    <message>
      <location filename="../../../ImageTools/_CommandImageScaling.py" line="182"/>
      <source>Select second point</source>
      <translation type="unfinished">Select second point</translation>
    </message>
    <message>
      <location filename="../../../ImageTools/_CommandImageScaling.py" line="191"/>
      <source>Select Image Plane and type distance</source>
      <translation type="unfinished">Select Image Plane and type distance</translation>
    </message>
  </context>
  <context>
    <name>Image_Scaling</name>
    <message>
      <location filename="../../../ImageTools/_CommandImageScaling.py" line="63"/>
      <source>Scale image plane</source>
      <translation type="unfinished">Scale image plane</translation>
    </message>
    <message>
      <location filename="../../../ImageTools/_CommandImageScaling.py" line="65"/>
      <source>Scales an image plane by defining a distance between two points</source>
      <translation type="unfinished">Scales an image plane by defining a distance between two points</translation>
    </message>
  </context>
  <context>
    <name>CmdCreateImagePlane</name>
    <message>
      <location filename="../../Command.cpp" line="101"/>
      <source>Image</source>
      <translation>Paveikslėlis</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="102"/>
      <source>Create image plane...</source>
      <translation>Sukurti vaizdo plokštumą...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="103"/>
      <source>Create a planar image in the 3D space</source>
      <translation>Sukurti plokštuminį vaizdą trimatėje erdvėje</translation>
    </message>
  </context>
  <context>
    <name>CmdImageOpen</name>
    <message>
      <location filename="../../Command.cpp" line="53"/>
      <source>Image</source>
      <translation>Paveikslėlis</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="54"/>
      <source>Open...</source>
      <translation>Atverti...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="55"/>
      <source>Open image view</source>
      <translation>Atidaryti vaizdo rodinį</translation>
    </message>
  </context>
  <context>
    <name>CmdImageScaling</name>
    <message>
      <location filename="../../Command.cpp" line="175"/>
      <source>Image</source>
      <translation>Paveikslėlis</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="176"/>
      <source>Scale...</source>
      <translation>Mastelis...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="177"/>
      <source>Image Scaling</source>
      <translation type="unfinished">Image Scaling</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::GLImageBox</name>
    <message>
      <location filename="../../GLImageBox.cpp" line="332"/>
      <location filename="../../OpenGLImageBox.cpp" line="384"/>
      <source>Image pixel format</source>
      <translation>Vaizdo taško formatas</translation>
    </message>
    <message>
      <location filename="../../GLImageBox.cpp" line="333"/>
      <location filename="../../OpenGLImageBox.cpp" line="385"/>
      <source>Undefined type of colour space for image viewing</source>
      <translation>Nenustatytas spalvų erdvės tipas vaizdo peržiūrai</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageOrientationDialog</name>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="14"/>
      <source>Choose orientation</source>
      <translation type="unfinished">Choose orientation</translation>
    </message>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="20"/>
      <source>Image plane</source>
      <translation>Atvaizdo plokštuma</translation>
    </message>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="26"/>
      <source>XY-Plane</source>
      <translation type="unfinished">XY-Plane</translation>
    </message>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="36"/>
      <source>XZ-Plane</source>
      <translation type="unfinished">XZ-Plane</translation>
    </message>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="43"/>
      <source>YZ-Plane</source>
      <translation type="unfinished">YZ-Plane</translation>
    </message>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="72"/>
      <source>Reverse direction</source>
      <translation type="unfinished">Reverse direction</translation>
    </message>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="81"/>
      <source>Offset:</source>
      <translation type="unfinished">Offset:</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageView</name>
    <message>
      <location filename="../../ImageView.cpp" line="111"/>
      <source>&amp;Fit image</source>
      <translation>&amp;Talpinti vaizdą</translation>
    </message>
    <message>
      <location filename="../../ImageView.cpp" line="113"/>
      <source>Stretch the image to fit the view</source>
      <translation>Priderinti vaizdą, kad tilptų peržiūros srityje</translation>
    </message>
    <message>
      <location filename="../../ImageView.cpp" line="117"/>
      <source>&amp;1:1 scale</source>
      <translation>&amp; 1:1 dydis</translation>
    </message>
    <message>
      <location filename="../../ImageView.cpp" line="119"/>
      <source>Display the image at a 1:1 scale</source>
      <translation>Rodyti vaizdą tikruoju dydžiu</translation>
    </message>
    <message>
      <location filename="../../ImageView.cpp" line="128"/>
      <source>Standard</source>
      <translation>Įprastinis</translation>
    </message>
    <message>
      <location filename="../../ImageView.cpp" line="146"/>
      <source>Ready...</source>
      <translation>Pasirengęs...</translation>
    </message>
    <message>
      <location filename="../../ImageView.cpp" line="539"/>
      <source>grey</source>
      <translation>pilka</translation>
    </message>
    <message>
      <location filename="../../ImageView.cpp" line="540"/>
      <location filename="../../ImageView.cpp" line="543"/>
      <location filename="../../ImageView.cpp" line="553"/>
      <location filename="../../ImageView.cpp" line="558"/>
      <location filename="../../ImageView.cpp" line="568"/>
      <location filename="../../ImageView.cpp" line="573"/>
      <location filename="../../ImageView.cpp" line="584"/>
      <location filename="../../ImageView.cpp" line="589"/>
      <location filename="../../ImageView.cpp" line="600"/>
      <location filename="../../ImageView.cpp" line="605"/>
      <source>zoom</source>
      <translation>priartinimas</translation>
    </message>
    <message>
      <location filename="../../ImageView.cpp" line="543"/>
      <location filename="../../ImageView.cpp" line="553"/>
      <location filename="../../ImageView.cpp" line="568"/>
      <location filename="../../ImageView.cpp" line="584"/>
      <location filename="../../ImageView.cpp" line="600"/>
      <source>outside image</source>
      <translation>išorinis vaizdas</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../Command.cpp" line="68"/>
      <location filename="../../Command.cpp" line="115"/>
      <source>Images</source>
      <translation>Vaizdai</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="73"/>
      <location filename="../../Command.cpp" line="120"/>
      <source>All files</source>
      <translation>Visi failai</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="75"/>
      <location filename="../../Command.cpp" line="122"/>
      <source>Choose an image file to open</source>
      <translation>Pasirinkite vaizdo failą atvėrimui</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="128"/>
      <source>Error opening image</source>
      <translation>Klaida atidarant paveikslėlį</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="129"/>
      <source>Could not load the chosen image</source>
      <translation>Nepavyko įkelti pasirinkto paveikslėlio</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="36"/>
      <source>Image</source>
      <translation>Paveikslėlis</translation>
    </message>
  </context>
</TS>

==> freecad_0.19.2+dfsg1.orig.tar.xz: FreeCAD-0.19.2/src/Mod/Image/Gui/Resources/translations/Image_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt" sourcelanguage="en">
  <context>
    <name>Image_Scaling</name>
    <message>
      <location filename="../../../ImageTools/_CommandImageScaling.py" line="63"/>
      <source>Scale image plane</source>
      <translation>Keisti paveikslo plokštumos dydį</translation>
    </message>
    <message>
      <location filename="../../../ImageTools/_CommandImageScaling.py" line="65"/>
      <source>Scales an image plane by defining a distance between two points</source>
      <translation>Pakeičia paveikslo plokštumos dydį nurodant atstumą tarp dviejų taškų</translation>
    </message>
  </context>
  <context>
    <name>Dialog</name>
    <message>
      <location filename="../../../ImageTools/_CommandImageScaling.py" line="134"/>
      <source>Scale image plane</source>
      <translation>Keisti paveikslo plokštumos dydį</translation>
    </message>
    <message>
      <location filename="../../../ImageTools/_CommandImageScaling.py" line="135"/>
      <source>Distance [mm]</source>
      <translation>Atstumas [mm]</translation>
    </message>
    <message>
      <location filename="../../../ImageTools/_CommandImageScaling.py" line="136"/>
      <source>Select first point</source>
      <translation>Pasirinkti pirmąjį tašką</translation>
    </message>
    <message>
      <location filename="../../../ImageTools/_CommandImageScaling.py" line="154"/>
      <source>&lt;font color='red'&gt;Enter distance&lt;/font&gt;</source>
      <translation>&lt;font color='red'&gt;Įvesti atstumą&lt;/font&gt;</translation>
    </message>
    <message>
      <location filename="../../../ImageTools/_CommandImageScaling.py" line="157"/>
      <source>&lt;font color='red'&gt;Select ImagePlane&lt;/font&gt;</source>
      <translation>&lt;font color='red'&gt;Pasirinkti paveikslo plokštumą&lt;/font&gt;</translation>
    </message>
    <message>
      <location filename="../../../ImageTools/_CommandImageScaling.py" line="182"/>
      <source>Select second point</source>
      <translation>Pasirinkti sekantį tašką</translation>
    </message>
    <message>
      <location filename="../../../ImageTools/_CommandImageScaling.py" line="191"/>
      <source>Select Image Plane and type distance</source>
      <translation>Parinkti paveikslo plokštumą ir įvesti atstumą</translation>
    </message>
  </context>
  <context>
    <name>CmdCreateImagePlane</name>
    <message>
      <location filename="../../Command.cpp" line="101"/>
      <source>Image</source>
      <translation>Paveikslėlis</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="102"/>
      <source>Create image plane...</source>
      <translation>Sukurti vaizdo plokštumą...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="103"/>
      <source>Create a planar image in the 3D space</source>
      <translation>Sukurti plokštuminį vaizdą trimatėje erdvėje</translation>
    </message>
  </context>
  <context>
    <name>CmdImageOpen</name>
    <message>
      <location filename="../../Command.cpp" line="53"/>
      <source>Image</source>
      <translation>Paveikslėlis</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="54"/>
      <source>Open...</source>
      <translation>Atverti...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="55"/>
      <source>Open image view</source>
      <translation>Atidaryti vaizdo rodinį</translation>
    </message>
  </context>
  <context>
    <name>CmdImageScaling</name>
    <message>
      <location filename="../../Command.cpp" line="175"/>
      <source>Image</source>
      <translation>Paveikslėlis</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="176"/>
      <source>Scale...</source>
      <translation>Mastelis...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="177"/>
      <source>Image Scaling</source>
      <translation>Paveikslo dydžio keitimas</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::GLImageBox</name>
    <message>
      <location filename="../../GLImageBox.cpp" line="332"/>
      <location filename="../../OpenGLImageBox.cpp" line="384"/>
      <source>Image pixel format</source>
      <translation>Vaizdo taško formatas</translation>
    </message>
    <message>
      <location filename="../../GLImageBox.cpp" line="333"/>
      <location filename="../../OpenGLImageBox.cpp" line="385"/>
      <source>Undefined type of colour space for image viewing</source>
      <translation>Nenustatytas spalvų erdvės tipas vaizdo peržiūrai</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageOrientationDialog</name>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="14"/>
      <source>Choose orientation</source>
      <translation type="unfinished">Choose orientation</translation>
    </message>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="20"/>
      <source>Image plane</source>
      <translation>Atvaizdo plokštuma</translation>
    </message>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="26"/>
      <source>XY-Plane</source>
      <translation type="unfinished">XY-Plane</translation>
    </message>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="36"/>
      <source>XZ-Plane</source>
      <translation type="unfinished">XZ-Plane</translation>
    </message>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="43"/>
      <source>YZ-Plane</source>
      <translation type="unfinished">YZ-Plane</translation>
    </message>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="72"/>
      <source>Reverse direction</source>
      <translation type="unfinished">Reverse direction</translation>
    </message>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="81"/>
      <source>Offset:</source>
      <translation type="unfinished">Offset:</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageView</name>
    <message>
      <location filename="../../ImageView.cpp" line="111"/>
      <source>&amp;Fit image</source>
      <translation>&amp;Talpinti vaizdą</translation>
    </message>
    <message>
      <location filename="../../ImageView.cpp" line="113"/>
      <source>Stretch the image to fit the view</source>
      <translation>Priderinti vaizdą, kad tilptų peržiūros srityje</translation>
    </message>
    <message>
      <location filename="../../ImageView.cpp" line="117"/>
      <source>&amp;1:1 scale</source>
      <translation>&amp; 1:1 dydis</translation>
    </message>
    <message>
      <location filename="../../ImageView.cpp" line="119"/>
      <source>Display the image at a 1:1 scale</source>
      <translation>Rodyti vaizdą tikruoju dydžiu</translation>
    </message>
    <message>
      <location filename="../../ImageView.cpp" line="128"/>
      <source>Standard</source>
      <translation>Įprastinis</translation>
    </message>
    <message>
      <location filename="../../ImageView.cpp" line="146"/>
      <source>Ready...</source>
      <translation>Pasirengęs...</translation>
    </message>
    <message>
      <location filename="../../ImageView.cpp" line="539"/>
      <source>grey</source>
      <translation>pilka</translation>
    </message>
    <message>
      <location filename="../../ImageView.cpp" line="540"/>
      <location filename="../../ImageView.cpp" line="543"/>
      <location filename="../../ImageView.cpp" line="553"/>
      <location filename="../../ImageView.cpp" line="558"/>
      <location filename="../../ImageView.cpp" line="568"/>
      <location filename="../../ImageView.cpp" line="573"/>
      <location filename="../../ImageView.cpp" line="584"/>
      <location filename="../../ImageView.cpp" line="589"/>
      <location filename="../../ImageView.cpp" line="600"/>
      <location filename="../../ImageView.cpp" line="605"/>
      <source>zoom</source>
      <translation>priartinimas</translation>
    </message>
    <message>
      <location filename="../../ImageView.cpp" line="543"/>
      <location filename="../../ImageView.cpp" line="553"/>
      <location filename="../../ImageView.cpp" line="568"/>
      <location filename="../../ImageView.cpp" line="584"/>
      <location filename="../../ImageView.cpp" line="600"/>
      <source>outside image</source>
      <translation>išorinis vaizdas</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../Command.cpp" line="68"/>
      <location filename="../../Command.cpp" line="115"/>
      <source>Images</source>
      <translation>Vaizdai</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="73"/>
      <location filename="../../Command.cpp" line="120"/>
      <source>All files</source>
      <translation>Visi failai</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="75"/>
      <location filename="../../Command.cpp" line="122"/>
      <source>Choose an image file to open</source>
      <translation>Pasirinkite vaizdo failą atvėrimui</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="128"/>
      <source>Error opening image</source>
      <translation>Klaida atidarant paveikslėlį</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="129"/>
      <source>Could not load the chosen image</source>
      <translation>Nepavyko įkelti pasirinkto paveikslėlio</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="36"/>
      <source>Image</source>
      <translation>Paveikslėlis</translation>
    </message>
  </context>
</TS>
